@@ -431,7 +431,7 @@ int fb_req(xmlDocPtr reqXml, xmlDocPtr* doc, const struct msa_module* info)
 {
     int init_status = 0;
     char* error_code = NULL;
-    xmlChar* class_val = NULL;
+    gchar* func_val = NULL;
     xmlNodePtr node = NULL;
     gchar* no_auth = NULL;
 
@@ -451,11 +451,12 @@ int fb_req(xmlDocPtr reqXml, xmlDocPtr* doc, const struct msa_module* info)
     if(node != NULL)
         no_auth = (gchar*) xmlGetProp(node, (xmlChar *)"noAuthorize");
 
-    class_val = get_req_class(reqXml);
-    if (g_strcmp0((char*) class_val, "settings") != 0)
+    func_val = get_req_function(reqXml);
+    if (g_strcmp0(func_val, "setSettings") != 0
+        && g_strcmp0(func_val, "getSettings") != 0)
         if(no_auth == NULL || g_strcmp0(no_auth, "true") != 0)
             init_status = initialization(cp);
-    g_free(class_val);
+    g_free(func_val);
 
     attempts = 0;
     if (init_status != 0) {
@@ -681,13 +682,13 @@ xmlChar* get_req_class(xmlDocPtr reqXml)
  * @param reqXml - request
  * @return function of request.
  */
-xmlChar* get_req_function(xmlDocPtr reqXml)
+gchar* get_req_function(xmlDocPtr reqXml)
 {
     xmlNodePtr rootNode = NULL;
     if (reqXml != NULL)
-	rootNode = xmlDocGetRootElement(reqXml);
+    	rootNode = xmlDocGetRootElement(reqXml);
     if (rootNode != NULL)
-	return xmlGetProp(rootNode, BAD_CAST FUNCTION);
+    	return (gchar*) xmlGetProp(rootNode, BAD_CAST FUNCTION);
     return NULL;
 }
 
